@@ -222,18 +222,18 @@ def range(freq, psd, z_hor=None, H=None, **params):
 
 
 def response_frac_redshift(frac, freq, psd, H=None, **params):
-    """Detector response distance in Mpc
+    """Detector response fraction redshift
 
     For the given detector noise PSD and waveform parameters return
-    the distance in Mpc at which the specified fraction of sources
-    would be detected (SNR >= DETECTION_SNR) if they were all placed
-    at that distance.  Assumes a uniform distribution of sources.
+    the redshift at which the specified fraction of sources would be
+    detected (SNR >= DETECTION_SNR) if they were all placed at that
+    distance.  Assumes a uniform distribution of sources.
 
     Remaining keyword arguments are interpreted as waveform generation
     parameters (see waveform.gen_waveform()), or a pre-generated
     fiducial waveform `H` may be provided (see waveform.CBCWaveform).
 
-    @returns distance in Mpc as a float
+    @returns redshift as a float
 
     """
     H = __H_from_args(freq, psd, H, params)
@@ -245,7 +245,7 @@ def response_frac_redshift(frac, freq, psd, H=None, **params):
 
 
 def response_frac(frac, freq, psd, H=None, **params):
-    """Detector response distance in Mpc
+    """Detector response fraction distance in Mpc
 
     See reach_frac_redshift().
 
@@ -320,24 +320,33 @@ def cosmological_ranges(freq, psd, H=None, **params):
     """
     H = __H_from_args(freq, psd, H, params)
 
-    z_hor = horizon_redshift(freq, psd, H=H)
-    hor = H.cosmo.luminosity_distance(z_hor)
+    hor_z = horizon_redshift(freq, psd, H=H)
+    hor = H.cosmo.luminosity_distance(hor_z)
 
-    cvol = volume(freq, psd, z_hor=z_hor, H=H)
+    cvol = volume(freq, psd, z_hor=hor_z, H=H)
     crange = util.v2r(cvol)
 
-    response_50 = response_frac(0.5, freq, psd, H=H)
-    response_10 = response_frac(0.1, freq, psd, H=H)
+    response_z_50 = response_frac_redshift(0.5, freq, psd, H=H)
+    response_50 = H.cosmo.luminosity_distance(response_z_50)
+    response_z_10 = response_frac_redshift(0.1, freq, psd, H=H)
+    response_10 = H.cosmo.luminosity_distance(response_z_10)
 
-    reach_50 = reach_frac(0.5, freq, psd, cvol=cvol, H=H)
-    reach_90 = reach_frac(0.9, freq, psd, cvol=cvol, H=H)
+    reach_z_50 = reach_frac_redshift(0.5, freq, psd, cvol=cvol, H=H)
+    reach_50 = H.cosmo.luminosity_distance(reach_z_50)
+    reach_z_90 = reach_frac_redshift(0.9, freq, psd, cvol=cvol, H=H)
+    reach_90 = H.cosmo.luminosity_distance(reach_z_90)
 
     return collections.OrderedDict([
         ('range',   (crange, 'Mpc')),
         ('horizon', (hor, 'Mpc')),
+        ('horizon_z',   (hor_z, None)),
+        ('response_z_50', (response_z_50, None)),
         ('response_50', (response_50, 'Mpc')),
+        ('response_z_10', (response_z_10, None)),
         ('response_10', (response_10, 'Mpc')),
+        ('reach_z_50', (reach_z_50, None)),
         ('reach_50', (reach_50, 'Mpc')),
+        ('reach_z_90', (reach_z_90, None)),
         ('reach_90', (reach_90, 'Mpc')),
         ])
 
